@@ -1032,13 +1032,14 @@ class Configuration(configparser.SafeConfigParser):
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
         cachekey=self._get_cachekey(url, parameters, headers)
-        if usecache and self._has_cachekey(cachekey):
+        if usecache and self._has_cachekey(cachekey) and not cachekey.startswith('file:'):
             logger.debug("#####################################\npagecache(POST) HIT: %s"%safe_url(cachekey))
             data,redirecturl = self._get_from_pagecache(cachekey)
             return data
 
         logger.debug("#####################################\npagecache(POST) MISS: %s"%safe_url(cachekey))
-        self.do_sleep(extrasleep)
+        if not cachekey.startswith('file:'): # don't sleep for file: URLs.
+            self.do_sleep(extrasleep)
 
         ## Request assumes POST when data!=None.  Also assumes data
         ## is application/x-www-form-urlencoded.
@@ -1085,7 +1086,7 @@ class Configuration(configparser.SafeConfigParser):
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
         cachekey=self._get_cachekey(url, parameters)
-        if usecache and self._has_cachekey(cachekey):
+        if usecache and self._has_cachekey(cachekey) and not cachekey.startswith('file:'):
             logger.debug("#####################################\npagecache(GET) HIT: %s"%safe_url(cachekey))
             data,redirecturl = self._get_from_pagecache(cachekey)
             class FakeOpened:
@@ -1098,7 +1099,8 @@ class Configuration(configparser.SafeConfigParser):
 
         logger.debug("#####################################\npagecache(GET) MISS: %s"%safe_url(cachekey))
         # print(self.get_pagecache().keys())
-        self.do_sleep(extrasleep)
+        if not cachekey.startswith('file:'): # don't sleep for file: URLs.
+            self.do_sleep(extrasleep)
 
         ## Specific UA because too many sites are blocking the default python UA.
         headers = [('User-Agent', self.getConfig('user_agent')),
