@@ -14,7 +14,7 @@ from zipfile import ZipFile, ZIP_STORED, ZIP_DEFLATED
 from xml.dom.minidom import parseString
 
 # py2 vs py3 transition
-from .six import text_type as unicode
+from .six import ensure_text, text_type as unicode
 from .six import string_types as basestring
 from .six import BytesIO # StringIO under py2
 
@@ -44,7 +44,7 @@ def get_update_data(inputio,
     contentdom = parseString(epub.read(rootfilename))
     firstmetadom = contentdom.getElementsByTagName("metadata")[0]
     try:
-        source=firstmetadom.getElementsByTagName("dc:source")[0].firstChild.data.encode("utf-8")
+        source=ensure_text(firstmetadom.getElementsByTagName("dc:source")[0].firstChild.data)
     except:
         source=None
 
